==> dif-core-2.1.6-3-20150130.185802-1-sources.jar: pt/digitalis/dif/dem/objects/parameters/constraints/impl/numeric/ParameterConstraintMaxImpl.java <==
/**
 * 2007, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */
package pt.digitalis.dif.dem.objects.parameters.constraints.impl.numeric;

import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;

import pt.digitalis.dif.dem.interfaces.IStageInstance;

/**
 * Max parameter constraint implementation
 * 
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 * @created Nov 16, 2007
 */
public class ParameterConstraintMaxImpl extends AbstractNumericParameterConstraint {

    /** Last tested value */
    Double lastTestedValue;

    /** Max value to compare to */
    Double maxValue;

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.IParameterConstraint#configureConstraint(java.lang.String)
     */
    public void configureConstraint(String configurationString)
    {

        String value = configurationString.substring(configurationString.indexOf("=") + 1);

        maxValue = new Double(value.trim());
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.AbstractParameterConstraint#getErrorMessageValues(boolean)
     */
    @Override
    protected Map<String, String> getErrorMessageValues(boolean parseValues)
    {
        Map<String, String> substitutions = new HashMap<String, String>();

        DecimalFormat df = new DecimalFormat("0");
        if (parseValues)
        {
            substitutions.put("value", df.format(lastTestedValue));
        }
        substitutions.put("max", df.format(maxValue));

        return substitutions;
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.IParameterConstraint#getJavaScriptValidationCondition()
     */
    public String getJavaScriptValidationCondition()
    {
        return "parseInt(value) <= " + maxValue;
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.impl.numeric.AbstractNumericParameterConstraint#validateConstraint(java.lang.Double,
     *      pt.digitalis.dif.dem.interfaces.IStageInstance)
     */
    @Override
    public boolean validateConstraint(Double value, IStageInstance stageInstance)
    {

        lastTestedValue = value;

        return (value != null && value <= maxValue);
    }
}

==> dif-core-2.1.9-5-20151216.121518-1-sources.jar: pt/digitalis/dif/dem/objects/parameters/constraints/impl/numeric/ParameterConstraintMaxImpl.java <==
/**
 * 2007, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */
package pt.digitalis.dif.dem.objects.parameters.constraints.impl.numeric;

import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;

import pt.digitalis.dif.dem.interfaces.IStageInstance;

/**
 * Max parameter constraint implementation
 * 
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 * @created Nov 16, 2007
 */
public class ParameterConstraintMaxImpl extends AbstractNumericParameterConstraint {

    /** Last tested value */
    Double lastTestedValue;

    /** Max value to compare to */
    Double maxValue;

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.IParameterConstraint#configureConstraint(java.lang.String)
     */
    public void configureConstraint(String configurationString)
    {

        String value = configurationString.substring(configurationString.indexOf("=") + 1);

        maxValue = new Double(value.trim());
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.AbstractParameterConstraint#getErrorMessageValues(boolean)
     */
    @Override
    protected Map<String, String> getErrorMessageValues(boolean parseValues)
    {
        Map<String, String> substitutions = new HashMap<String, String>();

        DecimalFormat df = new DecimalFormat("0");
        if (parseValues)
        {
            substitutions.put("value", df.format(lastTestedValue));
        }
        substitutions.put("max", df.format(maxValue));

        return substitutions;
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.IParameterConstraint#getJavaScriptValidationCondition()
     */
    public String getJavaScriptValidationCondition()
    {
        return "parseInt(value) <= " + maxValue;
    }

    /**
     * Inspector for the 'maxValue' attribute.
     * 
     * @return the maxValue value
     */
    public Double getMaxValue()
    {
        return maxValue;
    }

    /**
     * @see pt.digitalis.dif.dem.objects.parameters.constraints.impl.numeric.AbstractNumericParameterConstraint#validateConstraint(java.lang.Double,
     *      pt.digitalis.dif.dem.interfaces.IStageInstance)
     */
    @Override
    public boolean validateConstraint(Double value, IStageInstance stageInstance)
    {

        lastTestedValue = value;

        return (value != null && value <= maxValue);
    }
}
